A collection of functions for symbolic computation using 'Ryacas' package for structural equation models. This package includes functions to calculate model-implied covariance (and correlation) matrix and sampling covariance matrix of functions of variables using the first-order Taylor approximation. Reference: McArdle and McDonald (1984) <doi:10.1111/j.2044-8317.1984.tb00802.x>.
Mike W.-L. Cheung <mikewlcheung@nus.edu.sg>
Maintainer: Mike W.-L. Cheung <mikewlcheung@nus.edu.sg>
| Package: | symSEM |
| Type: | Package |
| Version: | 0.1 |
| Date: | 2020-07-15 |
| License: | GPL (>=2) |
| LazyLoad: | yes |